from django import template
from django.conf import settings
from fresh_media.hash_methods import get_token, FAIL_IF_NON_EXIST

import os.path
import urlparse

register = template.Library()


class FreshMediaNotFound(BaseException):
    pass


def _fresh(filename, path, url):
    try:
        token = get_token(path)
    except OSError:
        if FAIL_IF_NON_EXIST:
            raise FreshMediaNotFound("File `%s` not found." % path)
        else:
            return ""
    else:
        url = urlparse.urljoin(url, "%s?%s" % (filename, token))
        return url


@register.simple_tag
def media(filename):
    path = os.path.join(settings.MEDIA_ROOT, filename)
    url = settings.MEDIA_URL
    return _fresh(filename, path, url)

@register.simple_tag
def static(filename):
    path = os.path.join(settings.STATIC_ROOT, filename)
    url = settings.STATIC_URL
    return _fresh(filename, path, url)



from __future__ import with_statement
from django.conf import settings
from django.core.cache import cache

import os.path
from hashlib import md5

ALPHABET = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
BASE = len(ALPHABET)
METHOD = getattr(settings, 'FRESH_MEDIA_METHOD', 'atime').lower()
CACHE = int(getattr(settings, 'FRESH_MEDIA_CACHE_FOR', 0))
RAW = getattr(settings, 'FRESH_MEDIA_RAW', False)
FAIL_IF_NON_EXIST = getattr(settings, 'FRESH_MEDIA_FAIL_IF_NO_EXIST', True)


def method_md5(path):
    with open(path) as f:
        hash = md5(f.read()).hexdigest()
        if RAW:
            return hash
        else:
            return int(hash, 16)


methods = {
    'atime': lambda path: int(os.path.getmtime(path)),
    'md5': method_md5,
    'size': lambda path: os.path.getsize(path),
}


def convert(f):
    def wrap(path):
        num = f(path)
        st = ""
        while num:
            num, code = divmod(num, BASE)
            st += ALPHABET[code]
        return st
    return wrap


def cached(f):
    def wrap(path):
        cached_result = cache.get(path, None)
        if cached_result is None:
            result = f(path)
            cache.set(path, result, CACHE)
            return result
        else:
            return cached_result
    return wrap

get_token = methods[METHOD]

if CACHE > 0:
    get_token = cached(get_token)

if not RAW:
    get_token = convert(get_token)



from setuptools import setup, find_packages


setup(
    name='django-fresh-media',
    version='0.61',
    url='https://bitbucket.org/djangostars/django-fresh-media',
    license='BSD',
    author='Roman Osipenko',
    author_email='roman.osipenko@djangostars.com',
    description='Application to add hashes to media files',
    long_description='Application to add hashes to media files',
    keywords='django media hash browser',
    packages=['fresh_media', 'fresh_media/templatetags'],
    zip_safe=False,
    platforms='any',
    install_requires=[
        'Django'
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
